@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2015 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,9 +31,16 @@ namespace KeePass.Ecas
 			get { return m_evt; }
 		}
 
-		public EcasRaisingEventArgs(EcasEvent evt)
+		private EcasPropertyDictionary m_props;
+		public EcasPropertyDictionary Properties
+		{
+			get { return m_props; }
+		}
+
+		public EcasRaisingEventArgs(EcasEvent evt, EcasPropertyDictionary props)
 		{
 			m_evt = evt;
+			m_props = props;
 		}
 	}
 }
